﻿using System;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using SecretLabs.NETMF.Hardware;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

using Serial;

namespace TypeVarTD3
{
    public class Program
    {
        public static void Main()
        {
            // Constantes
            const Single ku = 4.83395E-3F, ki = 268.55E-6F, kui = 1.3E-6F;
            const UInt16 delay = 1000;

            // Variables
            UInt16 NU = 0, NI = 0;
            Single U1 = 0, I1 = 0, P1 = 0, P2 = 0;

            // Configuration des entrées / sorties 
            //Entrées
            // http://msdn.microsoft.com/en-us/library/hh421132.aspx (description de la classe AnalogInput)
            AnalogInput In_Uu = new AnalogInput(Cpu.AnalogChannel.ANALOG_5);
            AnalogInput In_UI = new AnalogInput(Cpu.AnalogChannel.ANALOG_4);
            //Sortie
            // http://webge.github.io/ELCD162/ (description de la classe ELCD162)
            SerialELCD162 LCD = new SerialELCD162(); // (LCD à connecter sur O5 de la carte Tinkerkit)

            LCD.Init(); LCD.ClearScreen();

            while (true)
            {
                // Lire
                NU = (UInt16)In_Uu.ReadRaw();
                NI = (UInt16)In_UI.ReadRaw();

                //Traiter
                // Solution 1: Coefficients appliqués avant la multiplication
                U1 = ku * NU; I1 = ki * NI;
                P1 = U1 * I1;

                // Solution 2: Coefficient appliqué après la multiplication
                P2 = kui * NU * NI;

                // Ecrire
                Debug.Print("NU=" + NU.ToString() + " et Ua=" + U1.ToString() +
                    "   NI=" + NI.ToString() + " et I=" + I1.ToString() +
                    " et P1=" + P1.ToString() + " et P2=" + P2.ToString());


                // Formatage du textes pour affichage sur le LCD
                // http://msdn.microsoft.com/en-us/library/dwhawy9k(v=vs.110).aspx
                LCD.ClearScreen();
                LCD.PutString("Ua=" + U1.ToString("N1") + "V  " + "I=" + I1.ToString("N1") + "A");
                LCD.SetCursor(0, 1);
                LCD.PutString("P=" + P1.ToString("N1") + "W");
                Thread.Sleep(delay);
            }
        }
    }
}